@@ -1,10 +1,12 @@
 package Devel::StackTrace;
-$Devel::StackTrace::VERSION = '1.34';
+
 use 5.006;
 
 use strict;
 use warnings;
 
+our $VERSION = '2.01';
+
 use Devel::StackTrace::Frame;
 use File::Spec;
 use Scalar::Util qw( blessed );
@@ -17,10 +19,8 @@ sub new {
     my $class = shift;
     my %p     = @_;
 
-    # Backwards compatibility - this parameter was renamed to no_refs
-    # ages ago.
-    $p{no_refs} = delete $p{no_object_refs}
-        if exists $p{no_object_refs};
+    $p{unsafe_ref_capture} = !delete $p{no_refs}
+        if exists $p{no_refs};
 
     my $self = bless {
         index  => undef,
@@ -47,6 +47,7 @@ sub _record_caller_data {
         = $self->{no_args}
         ? caller( $x++ )
         : do {
+            ## no critic (Modules::ProhibitMultiplePackages, Variables::ProhibitPackageVars)
             package    # the newline keeps dzil from adding a version here
                 DB;
             @DB::args = ();
@@ -56,17 +57,20 @@ sub _record_caller_data {
 
         my @args;
 
+        ## no critic (Variables::ProhibitPackageVars)
         @args = $self->{no_args} ? () : @DB::args;
+        ## use critic
 
         my $raw = {
             caller => \@c,
-            args => \@args,
+            args   => \@args,
         };
 
         next if $filter && !$filter->($raw);
 
-        if ( $self->{no_refs} ) {
-            $raw->{args} = [ map { ref $_ ? $self->_ref_to_string($_) : $_ } @{$raw->{args}} ];
+        unless ( $self->{unsafe_ref_capture} ) {
+            $raw->{args} = [ map { ref $_ ? $self->_ref_to_string($_) : $_ }
+                    @{ $raw->{args} } ];
         }
 
         push @{ $self->{raw} }, $raw;
@@ -82,10 +86,12 @@ sub _ref_to_string {
 
     return overload::AddrRef($ref) unless $self->{respect_overload};
 
+    ## no critic (Variables::RequireInitializationForLocalVars)
     local $@;
     local $SIG{__DIE__};
+    ## use critic
 
-    my $str = eval { $ref . '' };
+    my $str = eval { $ref . q{} };
 
     return $@ ? overload::AddrRef($ref) : $str;
 }
@@ -97,21 +103,23 @@ sub _make_frames {
 
     my $raw = delete $self->{raw};
     for my $r ( @{$raw} ) {
-        next if $filter && ! $filter->($r);
+        next if $filter && !$filter->($r);
 
         $self->_add_frame( $r->{caller}, $r->{args} );
     }
 }
 
-my $default_filter = sub { 1 };
+my $default_filter = sub {1};
 
 sub _make_frame_filter {
     my $self = shift;
 
     my ( @i_pack_re, %i_class );
     if ( $self->{ignore_package} ) {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $@;
         local $SIG{__DIE__};
+        ## use critic
 
         $self->{ignore_package} = [ $self->{ignore_package} ]
             unless eval { @{ $self->{ignore_package} } };
@@ -174,6 +182,7 @@ sub next_frame {
     }
     else {
         $self->{index} = undef;
+        ## no critic (Subroutines::ProhibitExplicitReturnUndef)
         return undef;
     }
 }
@@ -190,6 +199,7 @@ sub prev_frame {
         return $f[ --$self->{index} ];
     }
     else {
+        ## no critic (Subroutines::ProhibitExplicitReturnUndef)
         $self->{index} = undef;
         return undef;
     }
@@ -199,6 +209,8 @@ sub reset_pointer {
     my $self = shift;
 
     $self->{index} = undef;
+
+    return;
 }
 
 sub frames {
@@ -210,6 +222,7 @@ sub frames {
             if grep { !$_->isa('Devel::StackTrace::Frame') } @_;
 
         $self->{frames} = \@_;
+        delete $self->{raw};
     }
     else {
         $self->_make_frames() if $self->{raw};
@@ -237,7 +250,7 @@ sub as_string {
     my $self = shift;
     my $p    = shift;
 
-    my $st    = '';
+    my $st    = q{};
     my $first = 1;
     foreach my $f ( $self->frames() ) {
         $st .= $f->as_string( $first, $p ) . "\n";
@@ -248,7 +261,8 @@ sub as_string {
 }
 
 {
-    package
+    ## no critic (Modules::ProhibitMultiplePackages, ClassHierarchies::ProhibitExplicitISA)
+    package    # hide from PAUSE
         Devel::StackTraceFrame;
 
     our @ISA = 'Devel::StackTrace::Frame';
@@ -268,7 +282,7 @@ Devel::StackTrace - An object representing a stack trace
 
 =head1 VERSION
 
-version 1.34
+version 2.01
 
 =head1 SYNOPSIS
 
@@ -302,6 +316,8 @@ available from C<caller()>.
 This code was created to support my L<Exception::Class::Base> class (part of
 L<Exception::Class>) but may be useful in other contexts.
 
+=encoding UTF-8
+
 =head1 'TOP' AND 'BOTTOM' OF THE STACK
 
 When describing the methods of the trace object, I use the words 'top' and
@@ -352,9 +368,9 @@ false if it should be skipped.
 =item * filter_frames_early => $boolean
 
 If this parameter is true, C<frame_filter> will be called as soon as the
-stacktrace is created, and before refs are stringified (if C<no_refs> is
-true), rather than being filtered lazily when L<Devel::StackTrace::Frame>
-objects are first needed.
+stacktrace is created, and before refs are stringified (if
+C<unsafe_ref_capture> is not set), rather than being filtered lazily when
+L<Devel::StackTrace::Frame> objects are first needed.
 
 This is useful if you want to filter based on the frame's arguments and want
 to be able to examine object properties, for example.
@@ -381,13 +397,18 @@ stack trace. This prevents the frames from being captured at all, and applies
 before the C<frame_filter>, C<ignore_package>, or C<ignore_class> options,
 even with C<filter_frames_early>.
 
-=item * no_refs => $boolean
+=item * unsafe_ref_capture => $boolean
 
-If this parameter is true, then Devel::StackTrace will not store
-references internally when generating stacktrace frames. This lets
-your objects go out of scope.
+If this parameter is true, then Devel::StackTrace will store
+references internally when generating stacktrace frames.
 
-Devel::StackTrace replaces any references with their stringified
+B<This option is very dangerous, and should never be used with exception
+objects>. Using this option will keep any objects or references alive past
+their normal lifetime, until the stack trace object goes out of scope. It can
+keep objects alive even after their C<DESTROY> sub is called, resulting it it
+being called multiple times on the same object.
+
+If not set, Devel::StackTrace replaces any references with their stringified
 representation.
 
 =item * no_args => $boolean
@@ -488,9 +509,37 @@ or via email at bug-devel-stacktrace@rt.cpan.org.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Dagfinn Ilmari Mannsåker David Cantrell Graham Knop Mark Fowler Ricardo Signes
+
+=over 4
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+David Cantrell <david@cantrell.org.uk>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+Mark Fowler <mark@twoshortplanks.com>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2000 - 2016 by David Rolsky.
 
 This is free software, licensed under:
 
